import contextlib
import requests
from bs4 import BeautifulSoup
import click
import questionary
import io
from .getexam import getexam_core

BASE_URL = "https://fuoverflow.com"


class Exam:
    def __init__(self, title, url="None", label="None"):

        self.title = title
        self.url = url
        self.label = label

    def __repr__(self):
        return f"(title={self.title}, url={self.url}, label={self.label})\n"


@click.command()
@click.option("--code", help="Mã môn học để tìm kiếm tài liệu.", required=False)
def findexam(code=None):
    """
    Tìm kiếm tài liệu theo mã môn.
    """
    if not code:
        code = input("❗ Vui lòng cung cấp mã môn học: ")

    page = 1

    examsRaw = []

    while True:
        url = f"{BASE_URL}/forums/{code}/page-{page}"  # chỗ này có phân page. /page-1 là trang 1, /page-2 là trang 2, v.v1
        # print(f"🔍 Đang tìm kiếm tài liệu page: {page}")
        response = requests.get(url)
        # print(f"📶 Đang truy cập: {url}")
        if (response.url != url) & (page > 1):
            break  # nếu không có trang nào thì dừng lại
        # print(f"📶 HTTP status: {response.status_code}")

        soup = BeautifulSoup(response.text, "html.parser")
        examsRaw.extend(soup.find_all("div", class_="structItem-title"))
        page += 1

    if not examsRaw:
        print("⚠️ Không tìm thấy tài liệu nào cho mã môn này.")
        return
    print(f"✅ Đã tìm thấy {len(examsRaw)} tài liệu.")

    exams = []
    for exam in examsRaw:

        label = exam.find("span", class_="label").text.strip()
        title_link = exam.find_all("a")[-1]  # lấy thẻ a thứ 2
        title = title_link.text.strip()
        url = BASE_URL + title_link["href"]

        exams.append(Exam(title, url, label))

    choices = [
        questionary.Choice(f"{item.label} - {item.title}", value=item) for item in exams
    ]

    # Cho người dùng chọn
    selected_items = questionary.checkbox(
        "📚 Chọn tài liệu thi bạn muốn xử lý:", choices=choices
    ).ask()

    if not selected_items:
        return

    # In kết quả người dùng chọn
    print("\n✅ Các tài liệu bạn đã chọn:")
    for item in selected_items:
        print(f"📄 {item.label}-{item.title}")
    input("Nhấn Enter để tiếp tục...")
    # Xử lý các tài liệu đã chọn
    for item in selected_items:
        print(f"🔗 Đang xử lý tài liệu: {item.title}")
        # gọi hàm gêtxam mà không để nó log ra những dòng print trong đó
        status = getexam_core(url=item.url)
        if status:
            print(f"📥 Tài liệu {item.title} đã được xử lý thành công!\n")
