import click
import requests
from bs4 import BeautifulSoup
import re
import os
from tqdm import tqdm


BASE_URL = "https://fuoverflow.com"


@click.command()
@click.option("--id", help="Mã định danh tài liệu trên FuOverflow.", required=False)
@click.option("--url", help="URL đầy đủ của tài liệu FuOverflow.", required=False)
def getexam(id, url):
    """
    Tải ảnh từ thread bằng --id hoặc --url.\n

    Ví dụ:\n
      fuo getexam --id 1234\n
      fuo getexam --url https://fuoverflow.vn/thread/CSD_XXX_XXX.1234/\n
    """
    if not id and not url:
        print("❗ Vui lòng cung cấp --id hoặc --url.")
        return

    getexam_core(id, url)


def getexam_core(id=None, url=None):
    thread_url = ""
    if id:
        thread_url = f"{BASE_URL}/thread/{id}/"
    if url:
        thread_url = url
    if not thread_url:
        print("❗ Vui lòng cung cấp --id hoặc --url.")
        return False

    print(f"🔍 Đang kiểm tra tài liệu:\n {thread_url}")
    response = requests.get(thread_url)
    if response.status_code != 200:
        print("❌ Không thể tải trang, kiểm tra lại mã tài liệu hoặc kết nối mạng.")
        return False

    soup = BeautifulSoup(response.text, "html.parser")
    title = soup.find("h1", class_="p-title-value").text.strip()
    print(f"📶 Tìm thấy tài liệu: {title}")
    folder = f"Data_{title.replace(' ', '_').replace('/', '-')}"

    tags = soup.find_all("a", class_="file-preview")
    ids = []
    for tag in tags:
        href = tag.get("data-lb-sidebar-href")
        if href:
            match = re.search(r"\.(\d+)\/\?lightbox", href)
            if match:
                ids.append(match.group(1))

    if not ids:
        print("⚠️ Không tìm thấy nội dung trong tài liệu.")
        return False

    if not os.path.exists(folder):
        os.makedirs(folder)

    # ✅ Thay vòng lặp tải ảnh bằng tqdm để hiển thị thanh tiến độ
    for id in tqdm(ids, desc="📥 Tiến độ tải", unit="ảnh"):
        file_url = f"{BASE_URL}/media/{id}/full"
        resp = requests.get(file_url)
        if resp.status_code == 200:
            file_path = os.path.join(folder, f"{id}.jpg")
            with open(file_path, "wb") as f:
                f.write(resp.content)
        else:
            tqdm.write(f"❌ Lỗi tải {file_url} (status: {resp.status_code})")
            return False

    return True
